Welcome to Django Menu Generator’s documentation! — Django Menu Generator 1.0.1 documentation

# Welcome to Django Menu Generator’s documentation!

Django Menu Generator is a productivity tool that enables the generation of full featured menus through python dictionaries list, you only need to setup the HTML structure once for each menu you like to build and then use the dictionaries to generate menu items

## Features:

- Tested support to Python 2.7, 3.4, 3.5, 3.6
- Tested support to Django 1.8.18, 1.9.13, 1.10.7, 1.11
- No database
- Support unlimited menus
- Icons support
- Semi-Automatically identifies the selected item and his breadcrums
- Conditional menu items display through validators (Permissions, Authentications or whatever you want)

## Contents:

- Installation
- Usage
- Menu Generation
  - Generating menus through settings
  - Generating menus through apps
- URLs
  - Raw URLs
  - Reversible URLs
  - URL with args or kwargs
- Validators
  - Built-in validators
  - Custom validators
- CHANGELOG
  - 1.0.1(2017-04-29)
  - 1.0.0 (2017-04-09)
- Running the tests
- Contribute
- Support
- License
- Credits